vhost: accelerate metadata access through vmap()
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest3 patches 57 repliesIn review
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/3 | vhost: generalize adding used elemdrivers/ | +1 | 4 replies | |
| 1/3 | vhost: generalize adding used elemdrivers/ | +1 | 0 replies | |
| 2/3 | vhost: fine grain userspace memory accessorsdrivers/ | +77 | 0 replies | |
| 2/3 | vhost: fine grain userspace memory accessorsdrivers/ | +77 | 0 replies | |
| 3/3 | vhost: access vq metadata through kernel virtual addressdrivers/ drivers/ | +189 | 25 replies | |
| 3/3 | vhost: access vq metadata through kernel virtual addressdrivers/ drivers/ | +189 | 0 replies |
Reviews trailers per patch
No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.
Cover letter [PATCH net-next 0/3] vhost: accelerate metadata access through vmap()
Hi:
This series tries to access virtqueue metadata through kernel virtual address instead of copy_user() friends since they had too much overheads like checks, spec barriers or even hardware feature toggling.
Test shows about 24% improvement on TX PPS. It should benefit other cases as well.
Please review
Jason Wang (3):
vhost: generalize adding used elem
vhost: fine grain userspace memory accessors
vhost: access vq metadata through kernel virtual address
drivers/vhost/vhost.c | 281 ++++++++++++++++++++++++++++++++++++++---- drivers/vhost/vhost.h | 11 ++ 2 files changed, 266 insertions(+), 26 deletions(-)
Signature · 1 line
2.17.1